==> dhall-docs-1.0.11-138-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-docs
version:              1.0.11
visibility:           public
id:                   dhall-docs-1.0.11-2oavXru24g362bJekNfpzq
key:                  dhall-docs-1.0.11-2oavXru24g362bJekNfpzq
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  275eeb831369d926fe4d630a457449ba
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-docs-1.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-docs-1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.11-2oavXru24g362bJekNfpzq
depends:
    base-4.16.4.0 base16-bytestring-1.0.2.0-46ZA5fToFTG4nJXF5V42II
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptohash-sha256-0.11.102.1-2CVZSMuarDdBX9zBpo2mgi
    dhall-1.41.2-LxiROOc2A9o6Wu4bJFxtwj directory-1.3.6.2
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    lens-family-core-2.1.3-1OBIJmYHsnQ2CJGGRserxu
    lucid-2.11.20230408-58fKF6iPCi6KamWXDlUcik
    megaparsec-9.6.1-L1ZGjccQdofF1Rb6tkX7D0
    mmark-0.0.7.6-2391q1455fLGpffMKZsapJ mtl-2.2.2
    optparse-applicative-0.17.1.0-FmysOOLyJPZK6ulyCvrib9
    path-0.9.5-7tuwZi4KZVX9taYoAHFT9p
    path-io-1.8.2-B7x17i2VhFGlR6IQJFzsh
    prettyprinter-1.7.1-CIIVRJfY0omENAvTZv71tT text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> dhall-docs-1.0.11-139-x86_64.pkg.tar.zst: usr/share/haskell/register/dhall-docs.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 dhall-docs
version:              1.0.11
visibility:           public
id:                   dhall-docs-1.0.11-2RC0RBqndiv4uGCP9QeZaU
key:                  dhall-docs-1.0.11-2RC0RBqndiv4uGCP9QeZaU
license:              BSD-3-Clause
copyright:            2020 Germán Robayo
maintainer:           GenuineGabriella@gmail.com
author:               Germán Robayo
synopsis:             Generate HTML docs from a dhall package
description:
    Use this package if you want to create HTML documentation from your dhall
    packages:

    * See the "Dhall.Docs" module if you want to use this package as a library

    * Use the @dhall-docs@ program from this package if you want an executable

    The "Dhall.Docs" module also contains instructions for how to use this package

category:             Compiler
abi:                  948190194aa794b593797b013c30ed0e
exposed:              True
exposed-modules:      Dhall.Docs Dhall.Docs.Core
hidden-modules:
    Dhall.Docs.CodeRenderer Dhall.Docs.Comment Dhall.Docs.Embedded
    Dhall.Docs.Html Dhall.Docs.Markdown Dhall.Docs.Store
    Dhall.Docs.Util Paths_dhall_docs

import-dirs:          /usr/lib/ghc-9.2.8/site-local/dhall-docs-1.0.11
library-dirs:         /usr/lib/ghc-9.2.8/site-local/dhall-docs-1.0.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/dhall-docs
hs-libraries:         HSdhall-docs-1.0.11-2RC0RBqndiv4uGCP9QeZaU
depends:
    base-4.16.4.0 base16-bytestring-1.0.2.0-46ZA5fToFTG4nJXF5V42II
    bytestring-0.11.4.0 containers-0.6.5.1
    cryptohash-sha256-0.11.102.1-2CVZSMuarDdBX9zBpo2mgi
    dhall-1.41.2-HhaMK6FPesF8krPwT7xaS6 directory-1.3.6.2
    file-embed-0.0.15.0-4hNEx1vJ7JTC58fR03LKND filepath-1.4.2.2
    lens-family-core-2.1.3-1OBIJmYHsnQ2CJGGRserxu
    lucid-2.11.20230408-58fKF6iPCi6KamWXDlUcik
    megaparsec-9.6.1-L1ZGjccQdofF1Rb6tkX7D0
    mmark-0.0.7.6-2391q1455fLGpffMKZsapJ mtl-2.2.2
    optparse-applicative-0.17.1.0-FmysOOLyJPZK6ulyCvrib9
    path-0.9.5-7tuwZi4KZVX9taYoAHFT9p
    path-io-1.8.2-B7x17i2VhFGlR6IQJFzsh
    prettyprinter-1.7.1-CIIVRJfY0omENAvTZv71tT text-1.2.5.0
    transformers-0.5.6.2

haddock-interfaces:   /usr/share/doc/dhall-docs/html/dhall-docs.haddock
haddock-html:         /usr/share/doc/dhall-docs/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
